package cn.aiyangniu.api.common.config;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.serializer.SerializerFeature;
import org.springframework.data.redis.serializer.RedisSerializer;
import org.springframework.data.redis.serializer.SerializationException;
import java.nio.charset.Charset;
import java.nio.charset.StandardCharsets;

/**
 * FastJson 序列化 Redis
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
public class RedisSerialize<T> implements RedisSerializer<T> {

    /**
     * 默认编码格式
     */
    public static final Charset DEFAULT_CHARSET = StandardCharsets.UTF_8;

    private Class<T> clazz;

    public RedisSerialize(Class<T> clazz) {
        super();
        this.clazz = clazz;
    }

    @Override
    public byte[] serialize(T t) throws SerializationException {
        if(null == t) {
            return new byte[0];
        }
        return JSON.toJSONString(t, SerializerFeature.WriteClassName).getBytes(DEFAULT_CHARSET);
    }

    @Override
    public T deserialize(byte[] bytes) throws SerializationException {
        if(null == bytes || bytes.length <= 0) {
            return null;
        }
        String s = new String(bytes, DEFAULT_CHARSET);
        return (T) JSON.parseObject(s, clazz);
    }
}
