package cn.aiyangniu.api.common.util;

import cn.aiyangniu.api.common.entity.system.AuthEntity;
import cn.aiyangniu.api.common.entity.system.SysUserDto;
import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Component;
import javax.annotation.Resource;

/**
 * 权限工具类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Component
public class AuthUtil {

    @Resource
    private RedisUtil redisUtil;

    /**
     * setUserSession 将User对象存储到Redis数据库中
     *
     * @param userDto 用户对象
     * @param xAuthKey   Token
     */
    public void setUserSession(SysUserDto userDto, String xAuthKey) {
        String str = JSON.toJSONString(userDto);
        redisUtil.add("userId" + xAuthKey, str, 36000);
    }

    /**
     * delUserSession 删除Redis数据库中的User对象
     *
     * @param xAuthKey Token
     */
    public void delUserSession(String xAuthKey) {
        if(redisUtil.exists("userId" + xAuthKey)) {
            String userEntStr = redisUtil.get("userId" + xAuthKey).toString();
            JSONObject jo = JSONObject.parseObject(userEntStr);
            String userId = jo.getString("userId");
            if(redisUtil.exists("sysRandom" + userId)) {
                redisUtil.delete("sysRandom" + userId);
            }
            redisUtil.delete("userId" + xAuthKey);
        }
    }

    /**
     * hasLogin 判断用户是否登录
     *
     * @param xAuthKey Token
     * @return 返回是否登录标识
     */
    public boolean hasLogin(String xAuthKey) {
        if(redisUtil.exists("userId" + xAuthKey)) {
            if(redisUtil.getExpire("userId" + xAuthKey) < 0) {
                redisUtil.delete("userId" + xAuthKey);
            } else {
                redisUtil.update("userId" + xAuthKey, 36000);
                return true;
            }
        }
        return false;
    }

    /**
     * getUserSession 获取用户的session数据
     *
     * @param xAuthKey Token
     * @return 返回用户的session数据
     */
    public JSONObject getUserSession(String xAuthKey) {
        if(redisUtil.exists("userId" + xAuthKey)) {
            if(redisUtil.getExpire("userId" + xAuthKey) < 0) {
                redisUtil.delete("userId" + xAuthKey);
            } else {
                String userEntStr = redisUtil.get("userId" + xAuthKey);
                redisUtil.update("userId" + xAuthKey, 36000);
                return JSONObject.parseObject(userEntStr);
            }
        }
        return null;
    }

    /**
     * getUserId 从Redis数据库中获取User对象
     *
     * @param xAuthKey xAuthKey
     * @return 返回权限对象
     */
    public AuthEntity getUserId(String xAuthKey) {
        if(redisUtil.exists("userId" + xAuthKey)) {
            if(redisUtil.getExpire("userId" + xAuthKey) < 0) {
                redisUtil.delete("userId" + xAuthKey);
            } else {
                String userEntStr = redisUtil.get("userId" + xAuthKey).toString();
                redisUtil.update("userId" + xAuthKey, 36000);
                JSONObject jo = JSONObject.parseObject(userEntStr);
                if(jo != null) {
                    return new AuthEntity(true, jo.getString("userId"));
                }
            }
        }
        return new AuthEntity(false);
    }
}
