package cn.aiyangniu.api.common.util;

/**
 * CharacterFiltUtil 用于过滤请求参数的字符，以及判断字段串是否为整数或实例
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
public class CharacterFiltUtil {

    /**
     * inputFilter_文本框、传参过滤方法
     *
     * @param srcStr     源字符串
     * @param whiteSpace 是否去掉空格标识, true为去掉空格, false为保留空格
     * @return 过滤后的字符串
     */
    public static String inputFilter(String srcStr, boolean whiteSpace) {
        if(srcStr != null && !"".equals(srcStr)) {
            srcStr = srcStr.trim();
            srcStr = (srcStr.indexOf(" ") != -1 && whiteSpace ? srcStr.replace(" ", "") : srcStr);
            srcStr = (srcStr.indexOf("%") != -1 ? srcStr.replace("%", "\uff05") : srcStr);
            srcStr = (srcStr.indexOf("'") != -1 ? srcStr.replace("'", "\u2018") : srcStr);
            srcStr = (srcStr.indexOf("\"") != -1 ? srcStr.replace("\"", "\u201c") : srcStr);
            srcStr = (srcStr.indexOf("<") != -1 ? srcStr.replace("<", "&lt;") : srcStr);
            srcStr = (srcStr.indexOf(">") != -1 ? srcStr.replace(">", "&gt;") : srcStr);
            srcStr = (srcStr.indexOf("--") != -1 ? srcStr.replace("--", "\uff0d\uff0d") : srcStr);
            srcStr = (srcStr.indexOf("(") != -1 ? srcStr.replace("(", "") : srcStr);
            srcStr = (srcStr.indexOf(")") != -1 ? srcStr.replace(")", "") : srcStr);
            srcStr = (srcStr.indexOf("\n") != -1 ? srcStr.replace("\n", "<br />") : srcStr);
            srcStr = (srcStr.indexOf("\r") != -1 ? srcStr.replace("\r", "<br />") : srcStr);
        } else {
            srcStr = "";
        }
        return srcStr;
    }

    /**
     * searchFilter_搜索框过滤方法
     *
     * @param srcStr     源字符串
     * @param whiteSpace 是否去掉空格标识, true为去掉空格, false为保留空格
     * @return 过滤后的字符串
     */
    public static String searchFilter(String srcStr, boolean whiteSpace) {
        if(srcStr != null && !"".equals(srcStr)) {
            srcStr = srcStr.trim();
            srcStr = (srcStr.indexOf(" ") != -1 && whiteSpace ? srcStr.replace(" ", "") : srcStr);
            srcStr = (srcStr.indexOf("%") != -1 ? srcStr.replace("%", "\uff05") : srcStr);
            srcStr = (srcStr.indexOf("'") != -1 ? srcStr.replace("'", "\u2018") : srcStr);
            srcStr = (srcStr.indexOf("\"") != -1 ? srcStr.replace("\"", "\u201c") : srcStr);
            srcStr = (srcStr.indexOf("--") != -1 ? srcStr.replace("--", "\uff0d\uff0d") : srcStr);
            srcStr = (srcStr.indexOf("(") != -1 ? srcStr.replace("(", "") : srcStr);
            srcStr = (srcStr.indexOf(")") != -1 ? srcStr.replace(")", "") : srcStr);
        } else {
            srcStr = "";
        }
        return srcStr;
    }

    /**
     * textFilter_文本域过滤方法
     *
     * @param srcStr 源字符串
     * @return 过滤后的字符串
     */
    public static String textFilter(String srcStr) {
        if(srcStr != null && !"".equals(srcStr)) {
            srcStr = srcStr.trim();
            srcStr.replace(" ", "\u3000");
            srcStr = (srcStr.indexOf("%") != -1 ? srcStr.replace("%", "\uff05") : srcStr);
            srcStr = (srcStr.indexOf("'") != -1 ? srcStr.replace("'", "\u2018") : srcStr);
            srcStr = (srcStr.indexOf("\"") != -1 ? srcStr.replace("\"", "\u201c") : srcStr);
            srcStr = (srcStr.indexOf("<") != -1 ? srcStr.replace("<", "&lt;") : srcStr);
            srcStr = (srcStr.indexOf(">") != -1 ? srcStr.replace(">", "&gt;") : srcStr);
            srcStr = (srcStr.indexOf("--") != -1 ? srcStr.replace("--", "\uff0d\uff0d") : srcStr);
            srcStr = (srcStr.indexOf("(") != -1 ? srcStr.replace("(", "") : srcStr);
            srcStr = (srcStr.indexOf(")") != -1 ? srcStr.replace(")", "") : srcStr);
            srcStr = (srcStr.indexOf("\n") != -1 ? srcStr.replace("\n", "<br />") : srcStr);
            srcStr = (srcStr.indexOf("\r") != -1 ? srcStr.replace("\r", "<br />") : srcStr);
        } else {
            srcStr = "";
        }
        return srcStr;
    }

    /**
     * editorFilter_过滤文本编辑器的内容
     *
     * @param srcStr 文本编辑器的字符串
     * @return 过滤后的字符串
     */
    public static String editorFilter(String srcStr) {
        if(srcStr != null && !"".equals(srcStr)) {
            srcStr = (srcStr.indexOf("FRAME") != -1 ? srcStr.replace("FRAME", "") : srcStr);
            srcStr = (srcStr.indexOf("frame") != -1 ? srcStr.replace("frame", "") : srcStr);
            srcStr = (srcStr.indexOf("Frame") != -1 ? srcStr.replace("Frame", "") : srcStr);
        } else {
            srcStr = "";
        }
        return srcStr;
    }

    /**
     * urlFilter_过滤网址非法字符
     *
     * @param srcStr 网址的字符串
     * @return 过滤后的字符串
     */
    public static String urlFilter(String srcStr) {
        if(srcStr != null && !"".equals(srcStr)) {
            srcStr = (srcStr.indexOf(" ") != -1 ? srcStr.replace(" ", "") : srcStr);
            srcStr = (srcStr.indexOf("'") != -1 ? srcStr.replace("'", "") : srcStr);
            srcStr = (srcStr.indexOf("\"") != -1 ? srcStr.replace("\"", "") : srcStr);
            srcStr = (srcStr.indexOf(";") != -1 ? srcStr.replace(";", "") : srcStr);
            srcStr = (srcStr.indexOf("--") != -1 ? srcStr.replace("--", "") : srcStr);
            srcStr = (srcStr.indexOf("(") != -1 ? srcStr.replace("(", "") : srcStr);
            srcStr = (srcStr.indexOf(")") != -1 ? srcStr.replace(")", "") : srcStr);
        } else {
            srcStr = "";
        }
        return srcStr;
    }

    /**
     * 用于校验数字是否为整数
     *
     * @param str 被校验是否为整数的数字
     * @return 返回校验结果，true为是，false为不是
     */
    public static boolean isInt(String str) {
        str = str.replace(" ", "");
        boolean r = false;
        if(!"".equals(str)) {
            int b;
            for(int i = 0, c = str.length(); i < c; i++) {
                b = str.charAt(i);
                if(b < 48 || b > 57) {
                    r = false;
                    break;
                } else {
                    r = true;
                }
            }
        }
        return r;
    }

    /**
     * 用于校验输入的字符串是否为实数
     *
     * @param str 被校验是否为实数的字符串
     * @return 返回校验结果，true为是，false为不是
     */
    public static boolean isDub(String str) {
        str = str.replace(" ", "");
        boolean r = false;
        if(!"".equals(str)) {
            int a;
            for(int i = 0, c = str.length(); i < c; i++) {
                a = str.charAt(i);
                if((a < 48 || a > 57) && a != 45 && a != 46) {
                    r = false;
                    break;
                } else {
                    r = true;
                }
            }
        }
        return r;
    }
}
