package cn.aiyangniu.api.common.util;
import java.net.*;
import java.util.ArrayList;
import java.util.Enumeration;
import java.util.List;
import java.util.stream.Collectors;

/**
 * ClientIpUtil 获取客户端IP地址
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
public class ClientMacUtil {

    /**
     * getMacList 获取客户端设备的所有网络设备的MAC地址列表
     * 
     * @return MAC地址列表
     */
    public static List<String> getMacList() {
        StringBuilder sb = new StringBuilder();
        ArrayList<String> tmpMacList = new ArrayList<>();
        try {
            Enumeration<NetworkInterface> en = NetworkInterface.getNetworkInterfaces();
            while (en.hasMoreElements()) {
                NetworkInterface iface = en.nextElement();
                List<InterfaceAddress> addrs = iface.getInterfaceAddresses();
                for (InterfaceAddress addr : addrs) {
                    InetAddress ip = addr.getAddress();
                    NetworkInterface network;
                    network = NetworkInterface.getByInetAddress(ip);
                    if (network == null) {
                        continue;
                    }
                    byte[] mac = network.getHardwareAddress();
                    if (mac == null) {
                        continue;
                    }
                    sb.delete(0, sb.length());
                    for (int i = 0; i < mac.length; i++) {
                        sb.append(String.format("%02X%s", mac[i], (i < mac.length - 1) ? "-" : ""));
                    }
                    tmpMacList.add(sb.toString());
                }
            }
        } catch (SocketException e) {
            e.printStackTrace();
        }
        if (tmpMacList.size() <= 0) {
            return tmpMacList;
        }
        List<String> unique = tmpMacList.stream().distinct().collect(Collectors.toList());
        return unique;
    }
    public static void main(String[] args) {
        List<String> macs = getMacList();
        System.out.println("本机的mac网卡的地址有：" + macs);
    }
}