package cn.aiyangniu.api.common.util;

import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import java.io.BufferedReader;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.URL;
import java.nio.charset.StandardCharsets;

public class HttpRequest {

    /**
     * JAVA的http请求通用方法
     *
     * @param requestUrl    请求的地址
     * @param requestMethod 请求的方式，如GET、POST等
     * @param parms         请求的参数
     * @return 返回请求的结果
     */
    public static String httpRequest(String requestUrl, String requestMethod, String parms) {
        StringBuffer buffer = null;
        // System.out.println(parms);
        try {
            URL url = new URL(requestUrl);
            HttpURLConnection conn = (HttpURLConnection) url.openConnection();
            //设置通用的请求头属性
            conn.setRequestProperty("accept", "*/*");
            conn.setRequestProperty("connection", "Keep-Alive");
            conn.setRequestProperty("user-agent", "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1;SV1)");
            conn.setDoOutput(true);
            conn.setDoInput(true);
            conn.setRequestMethod(requestMethod);
            conn.connect();
            //往服务器端写内容 也就是发起http请求需要带的参数
            if(null != parms) {
                OutputStream os = conn.getOutputStream();
                os.write(parms.getBytes(StandardCharsets.UTF_8));
                os.close();
            }
            //读取服务器端返回的内容
            InputStream is = conn.getInputStream();
            InputStreamReader isr = new InputStreamReader(is, StandardCharsets.UTF_8);
            BufferedReader br = new BufferedReader(isr);
            buffer = new StringBuffer();
            String line;
            while((line = br.readLine()) != null) {
                buffer.append(line);
            }
            is.close();
            isr.close();
        } catch(Exception e) {
            e.printStackTrace();
        }
        assert buffer != null;
        return buffer.toString();
    }

    /**
     * JAVA的https请求通用方法
     *
     * @param requestUrl    请求的地址
     * @param requestMethod 请求的方式，如GET、POST等
     * @param outputStr     输出字符串
     * @return 返回请求的结果
     */
    public static String httpsRequest(String requestUrl, String requestMethod, String outputStr) {
        StringBuffer buffer = null;
        try {
            //创建SSLContext
            SSLContext sslContext = SSLContext.getInstance("SSL");
            TrustManager[] tm = {new MyX509TrustManager()};
            //初始化
            sslContext.init(null, tm, new java.security.SecureRandom());
            //获取SSLSocketFactory对象
            SSLSocketFactory ssf = sslContext.getSocketFactory();
            URL url = new URL(requestUrl);
            HttpsURLConnection conn = (HttpsURLConnection) url.openConnection();
            conn.setDoOutput(true);
            conn.setDoInput(true);
            conn.setUseCaches(false);
            conn.setRequestMethod(requestMethod);
            //设置当前实例使用的SSLSoctetFactory
            conn.setSSLSocketFactory(ssf);
            conn.connect();
            //往服务器端写内容
            if(null != outputStr) {
                OutputStream os = conn.getOutputStream();
                os.write(outputStr.getBytes(StandardCharsets.UTF_8));
                os.close();
            }
            //读取服务器端返回的内容
            InputStream is = conn.getInputStream();
            InputStreamReader isr = new InputStreamReader(is, StandardCharsets.UTF_8);
            BufferedReader br = new BufferedReader(isr);
            buffer = new StringBuffer();
            String line;
            while((line = br.readLine()) != null) {
                buffer.append(line);
            }
        } catch(Exception e) {
            e.printStackTrace();
        }
        assert buffer != null;
        return buffer.toString();
    }
}
