package cn.aiyangniu.api.common.util;

import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;
import javax.annotation.Resource;
import java.util.concurrent.TimeUnit;

/**
 * Redis 工具服务类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Component
public class RedisUtil {

    @Resource
    private RedisTemplate<String, Object> redisTemplate;

    /**
     * 保存数据
     *
     * @param key   键
     * @param value 值
     * @param time  时间(秒) 返回0代表为永久有效
     */
    public void add(String key, Object value, long time) {
        redisTemplate.opsForValue().set(key, value, time, TimeUnit.SECONDS);
    }

    /**
     * 删除Key
     *
     * @param key 可以传一个值 或多个
     */
    public void delete(String... key) {
        if(key!=null && key.length>0) {
            redisTemplate.delete(key[0]);
        }
    }

    /**
     * 获取Key对应的值
     *
     * @param key 键
     * @return 值
     */
    public <T> T get(String key) {
        return (T) redisTemplate.opsForValue().get(key);
    }

    /**
     * 获取过期时间
     *
     * @param key 键 不能为null
     * @return 时间(秒) 返回0代表为永久有效
     */
    public long getExpire(String key) {
        return redisTemplate.getExpire(key, TimeUnit.SECONDS);
    }

    /**
     * 修改失效时间
     *
     * @param key  键
     * @param time 时间（秒），返回0代表为永久有效
     */
    public void update(String key, long time) {
        try {
            redisTemplate.expire(key, time, TimeUnit.SECONDS);
        } catch(Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 判断key是否存在
     *
     * @param key 键
     * @return true 存在 false不存在
     */
    public boolean exists(String key) {
        return redisTemplate.hasKey(key);
    }
}
