package cn.aiyangniu.api.controller.system;

import cn.aiyangniu.api.common.entity.system.SysAreaEntity;
import cn.aiyangniu.api.common.entity.system.SysAreaVo;
import cn.aiyangniu.api.service.system.SysAreaService;
import cn.aiyangniu.api.common.util.CharacterFiltUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * SysAreaController 区域业务接口类
 *
 * @author Henry Hall
 * @since 2022-11-04
 */
@RestController
@Api(tags="地区选择接口")
@RequestMapping("/sysArea")
public class SysAreaController {

    @Resource
    private SysAreaService areaService;

    /**
     * selAreas 列表显示区域
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取地区列表")
    @RequestMapping(value="/select", method= RequestMethod.GET)
    @ApiImplicitParams({
        @ApiImplicitParam(name = "name", value = "名称", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "parentId", value = "父级编号", paramType = "query", dataType="int", dataTypeClass = Integer.class),
        @ApiImplicitParam(name = "level", value = "级别", paramType = "query", dataType="int", dataTypeClass = Integer.class)
    })
    public Map<String, Object> selAreas(String name, Integer level, Integer parentId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            name = CharacterFiltUtil.inputFilter(name, true);
            if(level==null || parentId==null || level==0 || parentId==0) {
                retCode = "100110090101";
                retMsg = "对不起，您请求的参数为空，请重试";
            } else {
                SysAreaVo areaVo = new SysAreaVo();
                areaVo.setName(name);
                areaVo.setAreaLevel(level);
                areaVo.setParentId(parentId);
                List<SysAreaEntity> areaEntities = areaService.selAreas(areaVo);
                if(areaEntities != null && areaEntities.size() > 0) {
                    result.put("data", areaEntities);
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110090105";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }
}
