package cn.aiyangniu.api.controller.system;

import cn.aiyangniu.api.common.entity.system.AuthEntity;
import cn.aiyangniu.api.common.entity.system.SysBtnEntity;
import cn.aiyangniu.api.common.entity.system.SysBtnVo;
import cn.aiyangniu.api.service.system.SysBtnService;
import cn.aiyangniu.api.common.util.AuthUtil;
import cn.aiyangniu.api.common.util.CharacterFiltUtil;
import cn.aiyangniu.api.common.util.RandomUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * 按钮业务接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Slf4j
@RestController
@Api(tags="操作按钮接口")
@RequestMapping("/sysButton")
public class SysBtnController {

    @Resource
    private SysBtnService btnService;

    @Resource
    private RandomUtil randomUtil;

    @Resource
    private AuthUtil authUtil;

    /**
     * saveBtn 新增/修改按钮
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "新增/修改按钮信息")
    @RequestMapping(value="/save", method= RequestMethod.POST)
    @ApiImplicitParam(name = "btnEntity", value = "模块信息实体对象", paramType = "body", dataType="SysBtnEntity", dataTypeClass = SysBtnEntity.class, required = true)
    public Map<String, Object> saveBtn(@RequestBody SysBtnEntity btnEntity, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, sysRandom, token, reqRandom, userId, btnId, btnName, btnCode, modId;
        int iSort, r;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                userId = auth.getUserId();
                sysRandom = randomUtil.getSysRandom(userId);
                btnId = btnEntity.getBtnId();
                btnName = btnEntity.getBtnName();
                btnCode = btnEntity.getBtnCode();
                modId = btnEntity.getModId();
                reqRandom = req.getParameter("reqRandom");
                btnId = CharacterFiltUtil.inputFilter(btnId, true);
                btnName = CharacterFiltUtil.inputFilter(btnName, true);
                btnCode = CharacterFiltUtil.inputFilter(btnCode, true);
                modId = CharacterFiltUtil.inputFilter(modId, true);
                reqRandom = CharacterFiltUtil.inputFilter(reqRandom, true);
                if("".equals(btnName) || "".equals(btnCode) || "0".equals(modId) || "".equals(reqRandom)) {
                    retCode = "100110030101";
                    retMsg = "对不起，您输入的信息有为空的必填项，请检查！";
                } else if(btnName.length() > 30 || btnCode.length() > 10) {
                    retCode = "100110030102";
                    retMsg = "对不起，您输入的信息有超出字数限制的项，请检查！";
                } else if(RandomUtil.verifySysRandom(reqRandom, sysRandom)) {
                    retCode = "100110030103";
                    retMsg = "对不起，您已经提交过了，请不要重复提交！";
                } else {
                    randomUtil.setSysRandom(userId);
                    btnEntity.setBtnName(btnName);
                    btnEntity.setBtnCode(btnCode);
                    btnEntity.setModId(modId);
                    btnEntity.setOptUser(userId);
                    if("".equals(btnId)) {
                        r = btnService.addBtn(btnEntity);
                    } else {
                        btnEntity.setBtnId(btnId);
                        r = btnService.edtBtn(btnEntity);
                    }
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，按钮保存成功！";
                    } else {
                        retCode = "100110030104";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * delBtns 删除按钮
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "删除按钮信息")
    @RequestMapping(value="/delete", method= RequestMethod.POST)
    @ApiImplicitParam(name = "btnVo", value = "模块信息实体对象", paramType = "body", dataType="SysBtnVo", dataTypeClass = SysBtnVo.class, required = true)
    public Map<String, Object> delBtns(@RequestBody SysBtnVo btnVo, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                if(btnVo.getBtnIds()==null || btnVo.getBtnIds().size()==0) {
                    retCode = "100110030201";
                    retMsg = "对不起，您提交的信息有为空的必填项，请检查！";
                } else {
                    btnVo.setOptUser(auth.getUserId());
                    int r = btnService.delBtns(btnVo);
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，按钮删除成功！";
                    } else {
                        retCode = "100110030204";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * getBtn 获取单一按钮
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取按钮详情信息")
    @RequestMapping(value="/getById", method= RequestMethod.GET)
    @ApiImplicitParam(name = "btnId", value = "按钮编号", paramType = "query", dataType="String", dataTypeClass = String.class, required = true)
    public Map<String, Object> getBtn(String btnId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        SysBtnEntity btnEntity;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                btnId = CharacterFiltUtil.inputFilter(btnId, true);
                if("".equals(btnId) || btnId.length() != 36) {
                    retCode = "100110030301";
                    retMsg = "对不起，您请求的参数非法，请重试！";
                } else {
                    btnEntity = btnService.getBtn(btnId);
                    if(btnEntity != null) {
                        result.put("data", btnEntity);
                        retCode = "1001";
                        retMsg = "查询成功。";
                    } else {
                        retCode = "100110030305";
                        retMsg = "暂无内容";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * listBtns 列表显示按钮
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取按钮分页列表")
    @RequestMapping(value="/page", method= RequestMethod.GET)
    @ApiImplicitParams({
        @ApiImplicitParam(name = "schName", value = "关键字", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "modId", value = "模块编号", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "offset", value = "开始数据", paramType = "query", dataType="int", dataTypeClass = Integer.class, required = true),
        @ApiImplicitParam(name = "limit", value = "每页数量", paramType = "query", dataType="int", dataTypeClass = Integer.class, required = true)
    })
    public Map<String, Object> listBtns(String schName, String modId, Integer offset, Integer limit, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                schName = CharacterFiltUtil.inputFilter(schName, true);
                modId = CharacterFiltUtil.inputFilter(modId, true);
                SysBtnVo btnVo = new SysBtnVo();
                btnVo.setSchName(schName);
                btnVo.setModId(modId);
                int pageNo = offset / limit + 1;
                IPage<SysBtnEntity> iPage = btnService.listBtns(btnVo, pageNo, limit);
                if(iPage != null && iPage.getRecords() != null && iPage.getRecords().size() > 0) {
                    result.put("data", iPage.getRecords());
                    result.put("total", iPage.getTotal());
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110030405";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * sortBtns 统计某按钮下的子按钮数量，用于自动排序
     */
    @ApiOperation(value = "获取按钮详情信息")
    @ApiImplicitParam(name = "modId", value = "模块编号", paramType = "query", dataType="String", dataTypeClass = String.class)
    @RequestMapping(value="/sort", method= RequestMethod.GET)
    private Map<String, Object> sortBtns(String modId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                modId = CharacterFiltUtil.inputFilter(modId, true);
                if("".equals(modId) || modId.length() != 36) {
                    retCode = "100110030501";
                    retMsg = "对不起，您请求的参数不正确，请重试！";
                } else {
                    int btnNum = btnService.sortBtns(modId);
                    result.put("data", btnNum);
                    retCode = "1001";
                    retMsg = "查询成功。";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }
}
