package cn.aiyangniu.api.controller.system;

import cn.aiyangniu.api.common.entity.system.AuthEntity;
import cn.aiyangniu.api.common.entity.system.SysOptEntity;
import cn.aiyangniu.api.common.entity.system.SysOptVo;
import cn.aiyangniu.api.service.system.SysOptService;
import cn.aiyangniu.api.common.util.AuthUtil;
import cn.aiyangniu.api.common.util.CharacterFiltUtil;
import cn.aiyangniu.api.common.util.PinyinUtil;
import cn.aiyangniu.api.common.util.RandomUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * SysOptController 选项业务接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Slf4j
@RestController
@Api(tags="数据字典接口")
@RequestMapping("/sysOption")
public class SysOptController {

    @Resource
    private SysOptService optService;

    @Resource
    private RandomUtil randomUtil;

    @Resource
    private AuthUtil authUtil;

    /**
     * saveOpt 新增/修改选项
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "新增/修改数据字典")
    @RequestMapping(value="/save", method= RequestMethod.POST)
    @ApiImplicitParam(name = "optEntity", value = "数据字典实体对象", paramType = "body", dataType="SysOptEntity", dataTypeClass = SysOptEntity.class, required = true)
    public Map<String, Object> saveOpt(@RequestBody SysOptEntity optEntity, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, sysRandom, token, reqRandom, userId, optId, optName, optCode, kind, sort, pinyin, jianpin;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                userId = auth.getUserId();
                sysRandom = randomUtil.getSysRandom(userId);
                optId = optEntity.getOptId();
                optName = optEntity.getOptName();
                optCode = optEntity.getOptCode();
                kind = optEntity.getKind();
                reqRandom = optEntity.getReqRandom();
                optId = CharacterFiltUtil.inputFilter(optId, true);
                optName = CharacterFiltUtil.inputFilter(optName, true);
                optCode = CharacterFiltUtil.inputFilter(optCode, true);
                kind = CharacterFiltUtil.inputFilter(kind, true);
                reqRandom = CharacterFiltUtil.inputFilter(reqRandom, true);
                if("".equals(optName) || "".equals(optCode) || "".equals(reqRandom)) {
                    retCode = "100110060101";
                    retMsg = "对不起，您输入的信息有为空的必填项，请检查！";
                } else if(optName.length() > 30 || optCode.length() > 10) {
                    retCode = "100110060102";
                    retMsg = "对不起，您输入的信息有超出字数限制的项，请检查！";
                } else if(RandomUtil.verifySysRandom(reqRandom, sysRandom)) {
                    retCode = "100110060103";
                    retMsg = "对不起，您已经提交过了，请不要重复提交！";
                } else {
                    randomUtil.setSysRandom(userId);
                    optEntity.setOptName(optName);
                    optEntity.setOptCode(optCode);
                    optEntity.setKind(kind);
                    pinyin = PinyinUtil.pinYin(optName);
                    jianpin = PinyinUtil.jianPin(optName);
                    optEntity.setPinyin(pinyin);
                    optEntity.setJianpin(jianpin);
                    optEntity.setOptUser(userId);
                    int r;
                    if("".equals(optId)) {
                        r = optService.addOpt(optEntity);
                    } else {
                        optEntity.setOptId(optId);
                        r = optService.edtOpt(optEntity);
                    }
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，选项保存成功！";
                    } else {
                        retCode = "100110060104";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * deleteOpt 删除选项
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "删除数据信息")
    @RequestMapping(value="/delete", method= RequestMethod.POST)
    @ApiImplicitParam(name = "optVo", value = "数据字典实体对象", paramType = "body", dataType="SysOptVo", dataTypeClass = SysOptVo.class, required = true)
    public Map<String, Object> deleteOpt(@RequestBody SysOptVo optVo, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                List<String> ids = optVo.getOptIds();
                if(ids==null || ids.size()>0) {
                    retCode = "100110060201";
                    retMsg = "对不起，您提交的信息有为空的必填项，请检查！";
                } else {
                    optVo.setOptUser(auth.getUserId());
                    int r = optService.delOpts(optVo);
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，选项删除成功！";
                    } else {
                        retCode = "100110060204";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * getOpt 获取单一选项
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取数据字典详情信息")
    @RequestMapping(value="/getById", method= RequestMethod.GET)
    @ApiImplicitParam(name = "optId", value = "主键编号", paramType = "query", dataType="string", dataTypeClass = String.class, required = true)
    public Map<String, Object> getOpt(String optId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        SysOptEntity optEntity;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                optId = CharacterFiltUtil.inputFilter(optId, true);
                if("".equals(optId) || optId.length() != 36) {
                    retCode = "100110060301";
                    retMsg = "对不起，您请求的参数非法，请重试！";
                } else {
                    optEntity = optService.getOpt(optId);
                    if(optEntity != null) {
                        result.put("data", optEntity);
                        retCode = "1001";
                        retMsg = "查询成功。";
                    } else {
                        retCode = "100110060305";
                        retMsg = "暂无内容";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * listOpts 列表显示选项
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取角色分页列表")
    @RequestMapping(value="/page", method= RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "schName", value = "关键字", paramType = "query", dataType="string", dataTypeClass = String.class),
            @ApiImplicitParam(name = "kind", value = "种类", paramType = "query", dataType="string", dataTypeClass = String.class),
            @ApiImplicitParam(name = "offset", value = "开始数据", paramType = "query", dataType="int", dataTypeClass = Integer.class, required = true),
            @ApiImplicitParam(name = "limit", value = "每页数量", paramType = "query", dataType="int", dataTypeClass = Integer.class, required = true)
    })
    public Map<String, Object> listOpts(String schName, String kind, Integer offset, Integer limit, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                schName = CharacterFiltUtil.inputFilter(schName, true);
                kind = CharacterFiltUtil.inputFilter(kind, true);
                SysOptVo optVo = new SysOptVo();
                optVo.setName(schName);
                optVo.setKind(kind);
                int pageNo = offset / limit + 1;
                IPage<SysOptEntity> iPage = optService.listOpts(optVo, pageNo, limit);
                if(iPage != null && iPage.getRecords() != null && iPage.getRecords().size() > 0) {
                    result.put("data", iPage.getRecords());
                    result.put("total", iPage.getTotal());
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110060405";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * selOpts 选择显示角色
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取角色下拉列表")
    @RequestMapping(value="/select", method= RequestMethod.GET)
    @ApiImplicitParams({
        @ApiImplicitParam(name = "schName", value = "关键字", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "kind", value = "种类", paramType = "query", dataType="string", dataTypeClass = String.class),
    })
    public Map<String, Object> selOpts(String schName, String kind, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                schName = CharacterFiltUtil.inputFilter(schName, true);
                kind = CharacterFiltUtil.inputFilter(kind, true);
                List<SysOptEntity> optEntities = optService.selOpts(schName, kind);
                if(optEntities != null && optEntities.size() > 0) {
                    result.put("data", optEntities);
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110060605";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * sortOpts 统计某选项下的子选项数量，用于自动排序
     */
    @ApiOperation(value = "获取数据字典的数量，用于排序")
    @RequestMapping(value="/sort", method= RequestMethod.GET)
    @ApiImplicitParam(name = "kind", value = "种类", paramType = "query", dataType="string", dataTypeClass = String.class)
    private Map<String, Object> sortOpts(String kind, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                kind = CharacterFiltUtil.inputFilter(kind, true);
                if("".equals(kind)) {
                    retCode = "100110060501";
                    retMsg = "对不起，您请求的参数不正确，请重试！";
                } else {
                    int optNum = optService.sortOpts(kind);
                    result.put("data", optNum);
                    retCode = "1001";
                    retMsg = "查询成功。";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }
}
