package cn.aiyangniu.api.controller.system;

import cn.aiyangniu.api.common.entity.system.*;
import cn.aiyangniu.api.service.system.SysRoleService;
import cn.aiyangniu.api.common.util.AuthUtil;
import cn.aiyangniu.api.common.util.CharacterFiltUtil;
import cn.aiyangniu.api.common.util.RandomUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * 角色业务接口类
 *
 * @author Henry Hall
 * @since 2020-09-28
 */
@Slf4j
@RestController
@Api(tags="用户角色接口")
@RequestMapping("/sysRole")
public class SysRoleController {

    @Resource
    private SysRoleService roleService;

    @Resource
    private RandomUtil randomUtil;

    @Resource
    private AuthUtil authUtil;

    /**
     * saveRole 新增/修改角色
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "新增/修改角色信息")
    @RequestMapping(value="/save", method= RequestMethod.POST)
    @ApiImplicitParam(name = "roleEntity", value = "角色实体对象", paramType = "body", dataType="SysRoleEntity", dataTypeClass = SysRoleEntity.class, required = true)
    public Map<String, Object> saveRole(@RequestBody SysRoleEntity roleEntity, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, sysRandom, token, reqRandom, userId, roleId, roleName, modCodes, btnCodes;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "10002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                userId = auth.getUserId();
                sysRandom = randomUtil.getSysRandom(userId);
                roleId = roleEntity.getRoleId();
                roleName = roleEntity.getRoleName();
                modCodes = roleEntity.getModCodes();
                btnCodes = roleEntity.getBtnCodes();
                reqRandom = roleEntity.getReqRandom();
                roleId = CharacterFiltUtil.inputFilter(roleId, true);
                roleName = CharacterFiltUtil.inputFilter(roleName, true);
                modCodes = CharacterFiltUtil.inputFilter(modCodes, true);
                btnCodes = CharacterFiltUtil.inputFilter(btnCodes, true);
                reqRandom = CharacterFiltUtil.inputFilter(reqRandom, true);
                if("".equals(roleName) || "".equals(modCodes) || "".equals(reqRandom)) {
                    retCode = "100110040101";
                    retMsg = "对不起，您输入的信息有为空的必填项，请检查！";
                } else if(roleName.length() > 30) {
                    retCode = "100110040102";
                    retMsg = "对不起，您输入的信息有超出字数限制的项，请检查！";
                } else if(RandomUtil.verifySysRandom(reqRandom, sysRandom)) {
                    retCode = "100110040103";
                    retMsg = "对不起，您已经提交过了，请不要重复提交！";
                } else {
                    randomUtil.setSysRandom(userId);
                    roleEntity.setRoleName(roleName);
                    roleEntity.setModCodes(modCodes);
                    roleEntity.setBtnCodes(btnCodes);
                    roleEntity.setOptUser(userId);
                    int r;
                    if("".equals(roleId)) {
                        r = roleService.addRole(roleEntity);
                    } else {
                        roleEntity.setRoleId(roleId);
                        r = roleService.edtRole(roleEntity);
                    }
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，角色保存成功！";
                    } else {
                        retCode = "100110040104";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * deleteRole 删除角色
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "删除角色信息")
    @RequestMapping(value="/delete", method= RequestMethod.POST)
    @ApiImplicitParam(name = "vo", value = "删除模块的请求对象", paramType = "body", dataType="SysRoleVo", dataTypeClass = SysRoleVo.class, required = true)
    public Map<String, Object> deleteRole(@RequestBody SysRoleVo roleVo, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                List<String> ids = roleVo.getRoleIds();
                if(ids==null || ids.size()==0) {
                    retCode = "100110040201";
                    retMsg = "对不起，您提交的信息有为空的必填项，请检查！";
                } else {
                    roleVo.setOptUser(auth.getUserId());
                    int r = roleService.delRoles(roleVo);
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，角色删除成功！";
                    } else {
                        retCode = "100110040204";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * getRole 获取单一角色
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取角色详情信息")
    @RequestMapping(value="/getById", method= RequestMethod.GET)
    @ApiImplicitParam(name = "roleId", value = "角色编号", paramType = "query", dataType="string", dataTypeClass = String.class, required = true)
    public Map<String, Object> getRole(String roleId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        SysRoleEntity roleEntity;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                roleId = CharacterFiltUtil.inputFilter(roleId, true);
                if("".equals(roleId) || roleId.length() != 36) {
                    retCode = "100110040301";
                    retMsg = "对不起，您请求的参数非法，请重试！";
                } else {
                    roleEntity = roleService.getRole(roleId);
                    if(roleEntity != null) {
                        result.put("data", roleEntity);
                        retCode = "1001";
                        retMsg = "查询成功。";
                    } else {
                        retCode = "100110040305";
                        retMsg = "暂无内容";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * listRoles 列表显示角色
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取角色分页列表")
    @RequestMapping(value="/page", method= RequestMethod.GET)
    @ApiImplicitParams({
            @ApiImplicitParam(name = "schName", value = "关键字", paramType = "query", dataType="string", dataTypeClass = String.class),
            @ApiImplicitParam(name = "display", value = "是否显示", paramType = "query", dataType="int", dataTypeClass = Integer.class),
            @ApiImplicitParam(name = "offset", value = "开始数据", paramType = "query", dataType="int", dataTypeClass = Integer.class, required = true),
            @ApiImplicitParam(name = "limit", value = "每页数量", paramType = "query", dataType="int", dataTypeClass = Integer.class, required = true)
    })
    public Map<String, Object> listRoles(String schName, Integer display, Integer offset, Integer limit, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        int iAuth, pageNo;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(!auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                schName = CharacterFiltUtil.inputFilter(schName, true);
                iAuth = (auth.getUserId().contains("gljsv") ? 1 : 2);
                SysRoleVo roleVo = new SysRoleVo();
                roleVo.setSchName(schName);
                roleVo.setAuth(iAuth);
                roleVo.setDisplay(display);
                pageNo = offset / limit + 1;
                IPage<SysRoleEntity> iPage = roleService.listRoles(roleVo, pageNo, limit);
                if(iPage != null && iPage.getRecords() != null && iPage.getRecords().size() > 0) {
                    result.put("data", iPage.getRecords());
                    result.put("total", iPage.getTotal());
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110040405";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * selRoles 选择显示角色
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取角色下拉列表")
    @RequestMapping(value="/select", method= RequestMethod.GET)
    public Map<String, Object> selRoles(HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(!auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                int kind = (!auth.getUserId().contains("gljsv") ? 1 : 2);
                List<SysRoleEntity> roleEntities = roleService.selRoles(kind);
                if(roleEntities != null && roleEntities.size() > 0) {
                    result.put("data", roleEntities);
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110040505";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }
}
