package cn.aiyangniu.api.controller.system;

import cn.aiyangniu.api.common.entity.system.AuthEntity;
import cn.aiyangniu.api.common.entity.system.SysTypeEntity;
import cn.aiyangniu.api.common.entity.system.SysTypeVo;
import cn.aiyangniu.api.service.system.SysTypeService;
import cn.aiyangniu.api.common.util.AuthUtil;
import cn.aiyangniu.api.common.util.CharacterFiltUtil;
import cn.aiyangniu.api.common.util.PinyinUtil;
import cn.aiyangniu.api.common.util.RandomUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.*;

/**
 * 分类业务接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Slf4j
@RestController
@Api(tags="通用分类接口")
@RequestMapping("/sysType")
public class SysTypeController {

    @Resource
    private SysTypeService typeService;

    @Resource
    private RandomUtil randomUtil;

    @Resource
    private AuthUtil authUtil;

    /**
     * saveType 新增/修改分类
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "新增/修改分类信息")
    @RequestMapping(value="/save", method= RequestMethod.POST)
    @ApiImplicitParam(name = "typeEntity", value = "分类实体对象", paramType = "body", dataType="SysTypeEntity", dataTypeClass = SysTypeEntity.class, required = true)
    public Map<String, Object> saveType(@RequestBody SysTypeEntity typeEntity,  HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, sysRandom, token, reqRandom, userId, typeId, typeName, typeCode, kind, parentId, typeImg, pinyin, jianpin;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                userId = auth.getUserId();
                sysRandom = randomUtil.getSysRandom(userId);
                typeId = typeEntity.getTypeId();
                typeName = typeEntity.getTypeName();
                typeCode = typeEntity.getTypeCode();
                kind = typeEntity.getKind();
                parentId = typeEntity.getParentId();
                typeImg = typeEntity.getTypeImg();
                reqRandom = typeEntity.getReqRandom();
                typeId = CharacterFiltUtil.inputFilter(typeId, true);
                typeName = CharacterFiltUtil.inputFilter(typeName, true);
                typeCode = CharacterFiltUtil.inputFilter(typeCode, true);
                kind = CharacterFiltUtil.inputFilter(kind, true);
                parentId = CharacterFiltUtil.inputFilter(parentId, true);
                typeImg = CharacterFiltUtil.inputFilter(typeImg, true);
                reqRandom = CharacterFiltUtil.inputFilter(reqRandom, true);
                if("".equals(typeName) || "".equals(parentId) || "".equals(kind) || "".equals(reqRandom)) {
                    retCode = "100110070101";
                    retMsg = "对不起，您输入的信息有为空的必填项，请检查！";
                } else if(typeName.length() > 30 || parentId.length() != 36) {
                    retCode = "100110070102";
                    retMsg = "对不起，您输入的信息有超出字数限制的项，请检查！";
                } else if(RandomUtil.verifySysRandom(reqRandom, sysRandom)) {
                    retCode = "100110070103";
                    retMsg = "对不起，您已经提交过了，请不要重复提交！";
                } else {
                    randomUtil.setSysRandom(userId);
                    typeEntity.setTypeName(typeName);
                    typeEntity.setTypeCode(typeCode);
                    typeEntity.setKind(kind);
                    typeEntity.setParentId(parentId);
                    typeEntity.setTypeImg(typeImg);
                    pinyin = PinyinUtil.pinYin(typeName);
                    jianpin = PinyinUtil.jianPin(typeName);
                    typeEntity.setPinyin(pinyin);
                    typeEntity.setJianpin(jianpin);
                    typeEntity.setOptUser(userId);
                    int r;
                    if("".equals(typeId)) {
                        r = typeService.addType(typeEntity);
                    } else {
                        typeEntity.setTypeId(typeId);
                        r = typeService.edtType(typeEntity);
                    }
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，分类保存成功！";
                    } else {
                        retCode = "100110070104";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * deleteType 删除分类
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "删除分类信息")
    @RequestMapping(value="/delete", method= RequestMethod.POST)
    @ApiImplicitParam(name = "typeVo", value = "角色实体对象", paramType = "body", dataType="SysTypeVo", dataTypeClass = SysTypeVo.class, required = true)
    public Map<String, Object> deleteType(@RequestBody SysTypeVo typeVo, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token, kind;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            AuthEntity auth = authUtil.getUserId(token);
            if(auth == null || !auth.isSuccess()) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                List<String> ids = typeVo.getTypeIds();
                kind = typeVo.getKind();
                kind = CharacterFiltUtil.inputFilter(kind, true);
                if(ids==null ||ids.size()==0 || "".equals(kind)) {
                    retCode = "100110070201";
                    retMsg = "对不起，您提交的信息有为空的必填项，请检查！";
                } else {
                    typeVo.setOptUser(auth.getUserId());
                    typeVo.setKind(kind);
                    typeVo.setName("");
                    int r = typeService.delTypes(typeVo);
                    if(r != 0) {
                        retCode = "1001";
                        retMsg = "恭喜您，分类删除成功！";
                    } else {
                        retCode = "100110070204";
                        retMsg = "对不起，系统错误，请联系系统管理员！";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * getType 获取单一分类
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取分类详情信息")
    @RequestMapping(value="/getById", method= RequestMethod.GET)
    @ApiImplicitParam(name = "typeId", value = "分类编号", paramType = "query", dataType="string", dataTypeClass = String.class, required = true)
    public Map<String, Object> getType(String typeId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        SysTypeEntity typeEntity;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                typeId = CharacterFiltUtil.inputFilter(typeId, true);
                if("".equals(typeId) || typeId.length() != 36) {
                    retCode = "100110070301";
                    retMsg = "对不起，您请求的参数非法，请重试！";
                } else {
                    typeEntity = typeService.getType(typeId);
                    if(typeEntity != null) {
                        result.put("data", typeEntity);
                        retCode = "1001";
                        retMsg = "查询成功。";
                    } else {
                        retCode = "100110070305";
                        retMsg = "暂无内容";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * listTypes 列表显示分类
     *
     * @param req 请求对象
     * @return 返回结果Json串
     */
    @ApiOperation(value = "获取分类树状列表")
    @RequestMapping(value="/list", method= RequestMethod.GET)
    @ApiImplicitParams({
        @ApiImplicitParam(name = "kind", value = "种类", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "parentId", value = "父级编号", paramType = "query", dataType="int", dataTypeClass = Integer.class)
    })
    public Map<String, Object> listTypes(String kind, String parentId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                kind = CharacterFiltUtil.inputFilter(kind, true);
                parentId = CharacterFiltUtil.inputFilter(parentId, true);
                parentId = parentId==null || "".equals(parentId) ? "00000000-0000-0000-0000-000000000000" : parentId;
                List<SysTypeEntity> typeEntities = typeService.listTypes(kind, parentId);
                if(typeEntities != null && typeEntities.size() > 0) {
                    result.put("data", typeEntities);
                    retCode = "1001";
                    retMsg = "查询成功。";
                } else {
                    retCode = "100110070405";
                    retMsg = "暂无内容";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * selTypes 下拉选择分类列表
     */
    @ApiOperation(value = "获取分类下拉列表")
    @RequestMapping(value="/select", method= RequestMethod.GET)
    @ApiImplicitParams({
        @ApiImplicitParam(name = "schName", value = "关键字", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "kind", value = "组织编号", paramType = "query", dataType="string", dataTypeClass = String.class),
        @ApiImplicitParam(name = "parentId", value = "职务编号", paramType = "query", dataType="string", dataTypeClass = String.class)
    })
    private Map<String, Object> selTypes(String schName, String kind, String parentId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                kind = CharacterFiltUtil.inputFilter(kind, true);
                schName = CharacterFiltUtil.inputFilter(schName, true);
                parentId = CharacterFiltUtil.inputFilter(parentId, true);
                if("".equals(parentId) || parentId.length() != 36 || "".equals(kind) || kind.length() != 36) {
                    retCode = "100110070501";
                    retMsg = "对不起，您请求的参数不正确，请重试！";
                } else {
                    SysTypeVo typeVo = new SysTypeVo();
                    typeVo.setKind(kind);
                    typeVo.setName(schName);
                    typeVo.setParentId(parentId);
                    List<SysTypeEntity> typeEntities = typeService.selTypes(typeVo);
                    if(typeEntities!=null && typeEntities.size()>0) {
                        result.put("entities", typeEntities);
                        retCode = "1001";
                        retMsg = "查询成功。";
                    } else {
                        retCode = "100110070505";
                        retMsg = "暂无内容";
                    }
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }

    /**
     * sortTypes 统计某分类下的子分类数量，用于自动排序
     */
    @ApiOperation(value = "获取分类下拉列表")
    @RequestMapping(value="/sort", method= RequestMethod.GET)
    @ApiImplicitParam(name = "parentId", value = "职务编号", paramType = "query", dataType="string", dataTypeClass = String.class)
    private Map<String, Object> sortTypes(String parentId, HttpServletRequest req) {
        Map<String, Object> result = new HashMap<>();
        String retCode, retMsg, token;
        token = req.getHeader("Authorization");
        if(token == null || "null".equals(token)) {
            retCode = "1002";
            retMsg = "对不起，您的操作非法，请登录！";
        } else {
            boolean auth = authUtil.hasLogin(token);
            if(!auth) {
                retCode = "1002";
                retMsg = "对不起，您没有登录或会话超时，请重新登录！";
            } else {
                parentId = CharacterFiltUtil.inputFilter(parentId, true);
                if("".equals(parentId) || parentId.length() != 36) {
                    retCode = "100110070601";
                    retMsg = "对不起，您请求的参数不正确，请重试！";
                } else {
                    int typeNum = typeService.sortTypes(parentId);
                    result.put("typeNum", typeNum);
                    retCode = "1001";
                    retMsg = "查询成功。";
                }
            }
        }
        result.put("code", retCode);
        result.put("msg", retMsg);
        return result;
    }
}
