package cn.aiyangniu.api.mapper.system;

import cn.aiyangniu.api.common.entity.system.SysBtnEntity;
import cn.aiyangniu.api.common.entity.system.SysBtnVo;
import cn.aiyangniu.api.common.entity.system.SysModVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;

/**
 * 按钮数据接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Mapper
public interface SysBtnMapper {

    /**
     * addBtn 新增按钮
     *
     * @param btnEntity 按钮实体对象
     * @return 返回新增结果
     */
    int addBtn(SysBtnEntity btnEntity);

    /**
     * delBtns 删除按钮
     *
     * @param sysBtnVo 按钮Vo对象
     * @return 返回删除结果
     */
    int delBtns(SysBtnVo sysBtnVo);

    /**
     * delBtnsByModId删除按钮
     *
     * @param sysModVo 按钮Vo对象
     * @return 返回删除结果
     */
    int delBtnsByModId(SysModVo sysModVo);

    /**
     * getBtn 获取单一按钮编号详情
     *
     * @param btnId 按钮编号
     * @return 返回详情结果
     */
    SysBtnEntity getBtn(String btnId);

    /**
     * edtBtn 修改按钮
     *
     * @param btnEntity 按钮实体对象
     * @return 返回修改结果
     */
    int edtBtn(SysBtnEntity btnEntity);

    /**
     * listBtns 列表展示按钮
     *
     * @param page 分页对象对象
     * @param sysBtnVo 按钮Vo对象
     * @return 返回新增结果
     */
    IPage<SysBtnEntity> listBtns(@Param("page") Page<SysBtnEntity> page, @Param("vo") SysBtnVo sysBtnVo);

    /**
     * sortBtns 统计子级按钮数量，用于排序
     *
     * @param modId 模块编号
     * @return 返回新增结果
     */
    int sortBtns(String modId);

    /**
     * selBtns 下拉选择展示按钮
     *
     * @return 返回新增结果
     */
    List<SysBtnEntity> selBtns();
}
