package cn.aiyangniu.api.mapper.system;

import cn.aiyangniu.api.common.entity.system.SysModEntity;
import cn.aiyangniu.api.common.entity.system.SysModVo;
import org.apache.ibatis.annotations.Mapper;
import java.util.List;
import java.util.Map;

/**
 * SysModMapper 系统模块数据接口类
 *
 * @author Henry Hall
 * @since 2020-09-28
 */
@Mapper
public interface SysModMapper {

    /**
     * addMod 新增模块
     *
     * @param modEntity 模块实体对象
     * @return 返回新增结果
     */
    int addMod(SysModEntity modEntity);

    /**
     * delMods 删除模块
     *
     * @param sysModVo 模块Vo对象
     * @return 返回删除结果
     */
    int delMods(SysModVo sysModVo);

    /**
     * getMod 获取单一模块编号详情
     *
     * @param modId 模块编号
     * @return 返回详情结果
     */
    SysModEntity getMod(String modId);

    /**
     * edtMod 修改模块
     *
     * @param modEntity 模块实体对象
     * @return 返回修改结果
     */
    int edtMod(SysModEntity modEntity);

    /**
     * listMods 列表展示模块
     *
     * @return 返回新增结果
     */
    List<SysModEntity> listMods();

    /**
     * selMods 下拉选择模块
     *
     * @return 返回新增结果
     */
    List<SysModEntity> selMods(String schName);

    /**
     * sortMods 统计子级模块数量，用于排序
     *
     * @param parentId 父级编号
     * @return 返回新增结果
     */
    int sortMods(String parentId);
}
