package cn.aiyangniu.api.mapper.system;

import cn.aiyangniu.api.common.entity.system.SysOptEntity;
import cn.aiyangniu.api.common.entity.system.SysOptVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;
import java.util.Map;

/**
 * SysOptMapper 选项数据接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Mapper
public interface SysOptMapper {

    /**
     * addOpt 新增选项
     *
     * @param optEntity 选项实体对象
     * @return 返回新增结果
     */
    int addOpt(SysOptEntity optEntity);

    /**
     * delOpts 删除选项
     *
     * @param sysOptVo 选项Vo对象
     * @return 返回删除结果
     */
    int delOpts(SysOptVo sysOptVo);

    /**
     * delOpts 删除选项
     *
     * @param sysOptVo 选项Vo对象
     * @return 返回删除结果
     */
    int delChildOpts(SysOptVo sysOptVo);

    /**
     * getOpt 获取单一选项编号详情
     *
     * @param optId 选项编号
     * @return 返回详情结果
     */
    SysOptEntity getOpt(String optId);

    /**
     * edtOpt 修改选项
     *
     * @param optEntity 选项实体对象
     * @return 返回修改结果
     */
    int edtOpt(SysOptEntity optEntity);

    /**
     * listOpts 列表展示选项
     *
     * @param page 分页对象对象
     * @param sysOptVo 选项Vo对象
     * @return 返回结果
     */
    IPage<SysOptEntity> listOpts(@Param("page") Page<SysOptEntity> page, @Param("vo") SysOptVo sysOptVo);

    /**
     * sortOpts 统计子级选项数量，用于排序
     *
     * @param kind 选项种类
     * @return 返回结果
     */
    int sortOpts(String kind);

    /**
     * selOpts 下拉选择展示选项
     *
     * @param reqMap 请求的名称及种类参数
     * @return 返回结果
     */
    List<SysOptEntity> selOpts(Map<String, String> reqMap);
}
