package cn.aiyangniu.api.mapper.system;

import cn.aiyangniu.api.common.entity.system.SysRoleEntity;
import cn.aiyangniu.api.common.entity.system.SysRoleVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;

/**
 * 角色数据接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Mapper
public interface SysRoleMapper {

    /**
     * addRole 新增角色
     *
     * @param roleEntity 角色实体对象
     * @return 返回新增结果
     */
    int addRole(SysRoleEntity roleEntity);

    /**
     * delRoles 删除角色
     *
     * @param sysRoleVo 角色Vo对象
     * @return 返回删除结果
     */
    int delRoles(SysRoleVo sysRoleVo);

    /**
     * getRole 获取单一角色编号详情
     *
     * @param roleId 角色编号
     * @return 返回详情结果
     */
    SysRoleEntity getRole(String roleId);

    /**
     * edtRole 修改角色
     *
     * @param roleEntity 角色实体对象
     * @return 返回修改结果
     */
    int edtRole(SysRoleEntity roleEntity);

    /**
     * listRoles 列表展示角色
     *
     * @param page 分页对象对象
     * @param sysRoleVo 角色Vo对象
     * @return 返回新增结果
     */
    IPage<SysRoleEntity> listRoles(@Param("page") Page<SysRoleEntity> page, @Param("vo") SysRoleVo sysRoleVo);

    /**
     * selRoles 下拉选择展示角色
     *
     * @param auth 是否有查看全部角色的权限
     * @return 返回新增结果
     */
    List<SysRoleEntity> selRoles(int auth);
}
