package cn.aiyangniu.api.mapper.system;

import cn.aiyangniu.api.common.entity.system.SysUserDto;
import cn.aiyangniu.api.common.entity.system.SysUserEntity;
import cn.aiyangniu.api.common.entity.system.SysUserVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import java.util.List;

/**
 * 用户数据接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Mapper
public interface SysUserMapper {

    /**
     * addUser 新增用户
     *
     * @param userEntity 用户实体对象
     * @return 返回新增结果
     */
    int addUser(SysUserEntity userEntity);

    /**
     * proUsers 删除用户
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回删除结果
     */
    int proUsers(SysUserVo sysUserVo);

    /**
     * getUser 获取单一用户编号详情
     *
     * @param userId 用户编号
     * @return 返回详情结果
     */
    SysUserEntity getUser(String userId);

    /**
     * edtUser 修改用户
     *
     * @param userEntity 用户实体对象
     * @return 返回修改结果
     */
    int edtUser(SysUserEntity userEntity);

    /**
     * listUsers 列表展示用户
     *
     * @param page 分页对象对象
     * @param sysUserVo 用户Vo对象
     * @return 返回新增结果
     */
    IPage<SysUserDto> listUsers(@Param("page") Page<SysUserDto> page, @Param("vo") SysUserVo sysUserVo);

    /**
     * selUsers 下拉选择展示用户
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回新增结果
     */
    List<SysUserDto> selUsers(SysUserVo sysUserVo);

    /**
     * extUser 根据账号查询重复的用户
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回新增结果
     */
    int extUser(SysUserVo sysUserVo);

    /**
     * loginUser 列表展示用户
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回新增结果
     */
    SysUserDto loginUser(SysUserVo sysUserVo);

    /**
     * updUser 修改个人资料
     *
     * @param userEntity 用户实体对象
     * @return 返回修改结果
     */
    int updUser(SysUserEntity userEntity);
}
