package cn.aiyangniu.api.service.impl.system;

import cn.aiyangniu.api.service.system.SysBtnService;
import cn.aiyangniu.api.common.entity.system.SysBtnEntity;
import cn.aiyangniu.api.common.entity.system.SysBtnVo;
import cn.aiyangniu.api.mapper.system.SysBtnMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * 按钮服务实现类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Service
public class SysBtnServiceImpl implements SysBtnService {

    @Resource
    private SysBtnMapper btnMapper;

    /**
     * addBtn 添加按钮
     *
     * @param btnEntity 按钮实体对象
     * @return 返回保存结果
     */
    @Override
    public int addBtn(SysBtnEntity btnEntity) {
        return btnMapper.addBtn(btnEntity);
    }

    /**
     * delBtns 删除按钮
     *
     * @param sysBtnVo 按钮Vo对象
     * @return 返回删除结果
     */
    @Override
    public int delBtns(SysBtnVo sysBtnVo) {
        return btnMapper.delBtns(sysBtnVo);
    }

    /**
     * getBtn 获取单一按钮
     *
     * @param btnId 按钮编号
     * @return 返回按钮对象
     */
    @Override
    public SysBtnEntity getBtn(String btnId) {
        return btnMapper.getBtn(btnId);
    }

    /**
     * edtBtn 修改按钮
     *
     * @param btnEntity 按钮实体对象
     * @return 返回修改结果
     */
    @Override
    public int edtBtn(SysBtnEntity btnEntity) {
        return btnMapper.edtBtn(btnEntity);
    }

    /**
     * listBtns 列表显示按钮
     *
     * @param sysBtnVo 按钮Vo对象
     * @return 返回按钮列表
     */
    @Override
    public IPage<SysBtnEntity> listBtns(SysBtnVo sysBtnVo, int pageNo, int pageSize) {
        Page<SysBtnEntity> page = new Page<>(pageNo, pageSize);
        return btnMapper.listBtns(page, sysBtnVo);
    }

    /**
     * sortBtns 统计子级按钮数量，用于排序
     *
     * @param modId 模块编号
     * @return 返回新增结果
     */
    @Override
    public int sortBtns(String modId) {
        return btnMapper.sortBtns(modId);
    }
}
