package cn.aiyangniu.api.service.impl.system;

import cn.aiyangniu.api.service.system.SysMsgService;
import cn.aiyangniu.api.common.entity.system.SysMsgEntity;
import cn.aiyangniu.api.common.entity.system.SysMsgVo;
import cn.aiyangniu.api.mapper.system.SysMsgMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;

/**
 * SysMsgServiceImpl 消息服务实现类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Service
public class SysMsgServiceImpl implements SysMsgService {

    @Resource
    private SysMsgMapper msgMapper;

    /**
     * addMsg 添加消息
     *
     * @param msgEntity 消息实体对象
     * @return 返回保存结果
     */
    @Override
    @Transactional
    public int addMsg(SysMsgEntity msgEntity) {
        msgMapper.addMsgDetail(msgEntity);
        return msgMapper.addMsg(msgEntity);
    }

    /**
     * delMsgs 已读、删除消息
     *
     * @param sysMsgVo 消息Vo对象
     * @return 返回删除结果
     */
    @Override
    public int proMsgs(SysMsgVo sysMsgVo) {
        return msgMapper.proMsgs(sysMsgVo);
    }

    /**
     * listMsgs 列表显示消息
     *
     * @param sysMsgVo 消息Vo对象
     * @return 返回消息列表
     */
    @Override
    public IPage<SysMsgEntity> listMsgs(SysMsgVo sysMsgVo, int pageNo, int pageSize) {
        Page<SysMsgEntity> page = new Page<>(pageNo, pageSize);
        return msgMapper.listMsgs(page, sysMsgVo);
    }

    /**
     * myMsgs 我的消息列表
     *
     * @param sysMsgVo 消息Vo对象
     * @return 返回消息列表
     */
    @Override
    public IPage<SysMsgEntity> myMsgs(SysMsgVo sysMsgVo, int pageNo, int pageSize) {
        Page<SysMsgEntity> page = new Page<>(pageNo, pageSize);
        return msgMapper.myMsgs(page, sysMsgVo);
    }

    /**
     * getMsg 获取单一消息
     *
     * @param msgId 消息编号
     * @return 返回消息对象
     */
    @Override
    public SysMsgEntity getMsg(String msgId) {
        return msgMapper.getMsg(msgId);
    }
}
