package cn.aiyangniu.api.service.impl.system;

import cn.aiyangniu.api.service.system.SysOptService;
import cn.aiyangniu.api.common.entity.system.SysOptEntity;
import cn.aiyangniu.api.common.entity.system.SysOptVo;
import cn.aiyangniu.api.mapper.system.SysOptMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * SysOptServiceImpl 选项服务实现类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Service
public class SysOptServiceImpl implements SysOptService {

    @Resource
    private SysOptMapper optMapper;

    /**
     * addOpt 添加选项
     *
     * @param optEntity 选项实体对象
     * @return 返回保存结果
     */
    @Override
    public int addOpt(SysOptEntity optEntity) {
        return optMapper.addOpt(optEntity);
    }

    /**
     * delOpts 删除选项
     *
     * @param sysOptVo 选项Vo对象
     * @return 返回删除结果
     */
    @Override
    public int delOpts(SysOptVo sysOptVo) {
        optMapper.delChildOpts(sysOptVo);
        return optMapper.delOpts(sysOptVo);
    }

    /**
     * getOpt 获取单一选项
     *
     * @param optId 选项编号
     * @return 返回选项对象
     */
    @Override
    public SysOptEntity getOpt(String optId) {
        return optMapper.getOpt(optId);
    }

    /**
     * edtOpt 修改选项
     *
     * @param optEntity 选项实体对象
     * @return 返回修改结果
     */
    @Override
    public int edtOpt(SysOptEntity optEntity) {
        return optMapper.edtOpt(optEntity);
    }

    /**
     * listOpts 列表显示选项
     *
     * @param sysOptVo 选项Vo对象
     * @return 返回选项列表
     */
    @Override
    public IPage<SysOptEntity> listOpts(SysOptVo sysOptVo, int pageNo, int pageSize) {
        Page<SysOptEntity> page = new Page<>(pageNo, pageSize);
        return optMapper.listOpts(page, sysOptVo);
    }

    /**
     * sortOpts 统计子级选项数量，用于排序
     *
     * @param kind 选项种类
     * @return 返回新增结果
     */
    @Override
    public int sortOpts(String kind) {
        return optMapper.sortOpts(kind);
    }

    /**
     * selOpts 下拉选择展示选项
     *
     * @param name 选项名称或编码的关键字
     * @param kind 选项种类
     * @return 返回新增结果
     */
    @Override
    public List<SysOptEntity> selOpts(String name, String kind) {
        Map<String, String> reqMap = new HashMap<>();
        reqMap.put("name", name);
        reqMap.put("kind", kind);
        return optMapper.selOpts(reqMap);
    }
}
