package cn.aiyangniu.api.service.impl.system;

import cn.aiyangniu.api.service.system.SysRoleService;
import cn.aiyangniu.api.common.entity.system.SysRoleEntity;
import cn.aiyangniu.api.common.entity.system.SysRoleVo;
import cn.aiyangniu.api.mapper.system.SysRoleMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 角色服务实现类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Service
public class SysRoleServiceImpl implements SysRoleService {

    @Resource
    private SysRoleMapper roleMapper;

    /**
     * addRole 添加角色
     *
     * @param roleEntity 角色实体对象
     * @return 返回保存结果
     */
    @Override
    public int addRole(SysRoleEntity roleEntity) {
        return roleMapper.addRole(roleEntity);
    }

    /**
     * delRoles 删除角色
     *
     * @param sysRoleVo 角色Vo对象
     * @return 返回删除结果
     */
    @Override
    public int delRoles(SysRoleVo sysRoleVo) {
        return roleMapper.delRoles(sysRoleVo);
    }

    /**
     * getRole 获取单一角色
     *
     * @param roleId 角色编号
     * @return 返回角色对象
     */
    @Override
    public SysRoleEntity getRole(String roleId) {
        return roleMapper.getRole(roleId);
    }

    /**
     * edtRole 修改角色
     *
     * @param roleEntity 角色实体对象
     * @return 返回修改结果
     */
    @Override
    public int edtRole(SysRoleEntity roleEntity) {
        return roleMapper.edtRole(roleEntity);
    }

    /**
     * listRoles 列表显示角色
     *
     * @param sysRoleVo 角色Vo对象
     * @return 返回角色列表
     */
    @Override
    public IPage<SysRoleEntity> listRoles(SysRoleVo sysRoleVo, int pageNo, int pageSize) {
        Page<SysRoleEntity> page = new Page<>(pageNo, pageSize);
        return roleMapper.listRoles(page, sysRoleVo);
    }

    /**
     * selRoles 下拉选择展示角色
     *
     * @param auth 是否有查看全部角色的权限
     * @return 返回新增结果
     */
    @Override
    public List<SysRoleEntity> selRoles(int auth) {
        return roleMapper.selRoles(auth);
    }

}
