package cn.aiyangniu.api.service.impl.system;

import cn.aiyangniu.api.service.system.SysUserService;
import cn.aiyangniu.api.common.entity.system.SysUserDto;
import cn.aiyangniu.api.common.entity.system.SysUserEntity;
import cn.aiyangniu.api.common.entity.system.SysUserVo;
import cn.aiyangniu.api.mapper.system.SysUserMapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * 用户服务实现类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
@Service
public class SysUserServiceImpl implements SysUserService {

    @Resource
    private SysUserMapper userMapper;

    /**
     * 添加用户
     *
     * @param userEntity 用户实体对象
     * @return 返回保存结果
     */
    @Override
    public int addUser(SysUserEntity userEntity) {
        return userMapper.addUser(userEntity);
    }

    /**
     * 删除用户
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回删除结果
     */
    @Override
    public int proUsers(SysUserVo sysUserVo) {
        return userMapper.proUsers(sysUserVo);
    }

    /**
     * 获取单一用户
     *
     * @param userId 用户编号
     * @return 返回用户对象
     */
    @Override
    public SysUserEntity getUser(String userId) {
        return userMapper.getUser(userId);
    }

    /**
     * 修改用户
     *
     * @param userEntity 用户实体对象
     * @return 返回修改结果
     */
    @Override
    public int edtUser(SysUserEntity userEntity) {
        return userMapper.edtUser(userEntity);
    }

    /**
     * 列表显示用户
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回用户列表
     */
    @Override
    public IPage<SysUserDto> listUsers(SysUserVo sysUserVo, int pageNo, int pageSize) {
        Page<SysUserDto> page = new Page<>(pageNo, pageSize);
        return userMapper.listUsers(page, sysUserVo);
    }

    /**
     * 下拉选择用户列表
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回用户列表
     */
    @Override
    public List<SysUserDto> selUsers(SysUserVo sysUserVo) {
        return userMapper.selUsers(sysUserVo);
    }

    /**
     * 判断登录账号是否重复
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回用户列表
     */
    @Override
    public int extUser(SysUserVo sysUserVo) {
        return userMapper.extUser(sysUserVo);
    }

    /**
     * 用户登录
     *
     * @param sysUserVo 用户Vo对象
     * @return 返回用户列表
     */
    @Override
    public SysUserDto loginUser(SysUserVo sysUserVo) {
        return userMapper.loginUser(sysUserVo);
    }

    /**
     * 修改个人资料
     *
     * @param userEntity 用户实体对象
     * @return 返回用户列表
     */
    @Override
    public int updUser(SysUserEntity userEntity) {
        return userMapper.updUser(userEntity);
    }
}
