package cn.aiyangniu.api.service.system;

import cn.aiyangniu.api.common.entity.system.SysModEntity;
import java.util.List;
import java.util.Map;

/**
 * 系统模块服务接口类
 *
 * @author Henry Hall
 * @since 2020-08-08
 */
public interface SysModService {

    /**
     * addMod 新增模块
     *
     * @param modEntity 模块实体对象
     * @return 返回新增结果
     */
    int addMod(SysModEntity modEntity);

    /**
     * delMods 删除模块
     *
     * @param userId 操作人员编号
     * @param modIds 模块编号串
     * @return 返回删除结果
     */
    int delMods(String userId, List<String> modIds);

    /**
     * getMod 获取单一模块编号详情
     *
     * @param modId 模块编号
     * @return 返回详情结果
     */
    SysModEntity getMod(String modId);

    /**
     * edtMod 修改模块
     *
     * @param modEntity 模块实体对象
     * @return 返回修改结果
     */
    int edtMod(SysModEntity modEntity);

    /**
     * listMods 列表展示模块
     *
     * @param parentId 父级编号
     * @return 返回结果
     */
    List<SysModEntity> listMods(String parentId);

    /**
     * selMods 下拉选择模块
     *
     * @param kind 查询种类，1为查询全部，2为查询当前用户所拥有的
     * @param userMods 当前用户所拥有的模块
     * @return 返回结果
     */
    List<SysModEntity> selMods(String kind, String parentId, String schName, String userMods);

    /**
     * sortMods 统计子级模块数量，用于排序
     *
     * @param parentId 父级编号
     * @return 返回结果
     */
    int sortMods(String parentId);

    /**
     * getModBtns 获取模块及拥有的按钮数据
     *
     * @return 返回新增结果
     */
    List<SysModEntity> getModBtns();
}
